@@ -63,7 +63,7 @@ class Client:
         Deploy an API.
 
         Args:
-            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.32/ for schema.
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.33/ for schema.
             predictor: A Cortex Predictor class implementation. Not required for TaskAPI/TrafficSplitter kinds.
             task: A callable class/function implementation. Not required for RealtimeAPI/BatchAPI/TrafficSplitter kinds.
             requirements: A list of PyPI dependencies that will be installed before the predictor class implementation is invoked.
@@ -165,8 +165,6 @@ class Client:
                 predictor_type = "python"
             if predictor.__name__ == "TensorFlowPredictor":
                 predictor_type = "tensorflow"
-            if predictor.__name__ == "ONNXPredictor":
-                predictor_type = "onnx"
 
             api_spec["predictor"]["path"] = impl_rel_path
             api_spec["predictor"]["type"] = predictor_type
